# ADA – Actigraphic Data Analyzer
ADA stands for Actigraphic Data Analyzer, coincidentally being also the name of the first programmer in the world.
It is an open source Python module for processing, analyzing and visualizing actigraphic data, with the main focus on bedtime sleep/wake classification and circadian rhythms analysis.
ADA is usable in form of a python package, and in form of standalone application with graphical interface (GUI).

## Installation
To install the module use pip:

```shell
pip install acti-data-analyzer
```

The GUI for Windows 10 and Windows 11 is availabe as a standalone executable from TODO WHERRE IT WILL BE??. Alternatively, GUI can be run on any system as a Python script, best within a venv. To do so, one may:

* Clone this repository (or download as a .zip and extract).
* Install the package and dependencies using `pip install acti-data-analyzer[gui]`.
* Run the gui by running `run_gui.py` script.

## Main features

* Reading and writing data from:
  * GENEActiv .bin and .csv files
  * Actigraph Corp .gt3x and .csv files
  * The MESA dataset.
* Converting data to native .ada format (much more efficient in terms of disk space and reading speed).
* Multiple algorithms allowing collapsing into epochs:
  * MIMS
  * ActivityIndex
  * ENMO
  * Resampling
  * Cole-Kripke
* Sleep/wake scoring using multiple algorithms:
  * Cole-Kripke
  * Webster
  * Scripps Clinic
  * UCSD
  * Sazonov
  * Unified Filter, with possibility of custom filter construction.
* Estimating multiple sleep metrics:
  * Sleep efficiency
  * Sleep fragmentation index
  * Sleep onset latency
  * Wake after sleep onset
  * And more.
* Assessing circadian rhythms:
  * Single and multi-component cosinor in linear and nonlinear variants
  * Sigmoidally-transformed cosinor
  * Spectrum estimator using autoregressive model
  * Detrended Fluctuation Analysis
  * Nonparametric measures: Interdaily Stability, Intradaily Variability, M10, L5.
* Easy to read and analyze summaries of sleep/wake and circadian assessments for multiple subjects.
* Automatic and customizable synchronization of actigraphic data with PSG staging.
* Plotting of all analysis steps.

Full documentation together with usage tutorial can be found under the [link](https://fuw_software.gitlab.io/aktygrafy/).
